@@ -1,7 +1,9 @@
 use strict;
 use warnings;
 package Data::Section;
-our $VERSION = '0.100770';
+{
+  $Data::Section::VERSION = '0.101622';
+}
 # ABSTRACT: read multiple hunks of data out of your DATA section
 
 use MRO::Compat 0.09;
@@ -14,7 +16,19 @@ use Sub::Exporter 0.979 -setup => {
 sub _mk_reader_group {
   my ($mixin, $name, $arg, $col) = @_;
   my $base = $col->{INIT}{into};
-  my $header_re = $arg->{header_re} || qr/\A_+\[\s*([^\]]+?)\s*\]_+\Z/;
+
+  my $default_header_re = qr/
+    \A                # start
+      _+\[            # __[
+        \s*           # any whitespace
+          ([^\]]+?)   # this is the actual name of the section
+        \s*           # any whitespace
+      \]_+            # ]__
+      [\x0d\x0a]{1,2} # possible cariage return for windows files
+    \z                # end
+  /x;
+
+  my $header_re = $arg->{header_re} || $default_header_re;
   $arg->{inherit} = 1 unless exists $arg->{inherit};
 
   my %export;
@@ -119,6 +133,7 @@ sub _mk_reader_group {
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -127,7 +142,7 @@ Data::Section - read multiple hunks of data out of your DATA section
 
 =head1 VERSION
 
-version 0.100770
+version 0.101622
 
 =head1 SYNOPSIS
 
@@ -210,7 +225,8 @@ By default, named sections are delimited by lines that look like this:
 
 You can use as many underscores as you want, and the space around the name is
 optional.  This pattern can be configured with the C<header_re> option (see
-above).
+above).  If present, a single leading C<\> is removed, so that sections can
+encode lines that look like section delimiters.
 
 When a line containing only C<__END__> is reached, all processing of sections
 ends.
@@ -231,7 +247,7 @@ package data for all the classes from which the invocant inherits -- as long as
 those classes also inherit from the package into which Data::Section was
 imported.
 
-In other words, given this inheritence tree:
+In other words, given this inheritance tree:
 
   A
    \
@@ -312,7 +328,16 @@ data section in the correct package.
 
 =head1 SEE ALSO
 
+=over 4
+
+=item *
+
+L<article for RJBS Advent 2009|http://advent.rjbs.manxome.org/2009/2009-12-09.html>
+
+=item *
+
 L<Inline::Files|Inline::Files> does something that is at first look similar,
+
 but it works with source filters, and contains the warning:
 
   It is possible that this module may overwrite the source code in files that
@@ -321,16 +346,17 @@ but it works with source filters, and contains the warning:
 
 Enough said.
 
+=back
+
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2008 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
